#!/bin/bash
#Automatically Created by slkbuild 0.6.1
#Maintainer: Thorsten Muehlfelder <thenktor(at)gmx.de>
#url: http://www.videolan.org/

######Begin Redundant Code######################################
check_for_root() {
	if [ "$UID" != "0" ]; then
		echo "You need to be root"
		exit 1
	fi
}

clean_dirs () {
        for COMPLETED in src pkg; do
                if [ -e $COMPLETED ]; then
                        rm -rf $COMPLETED
                fi
        done
}

clean_old_builds () {
	rm -rf $package.{t[xlgb]z,md5}
	clean_dirs
}

set_pre_permissions() {
	cd $startdir/src
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;
}


gzip_man_and_info_pages() {
	for DOCS in man info; do
		if [ -d "$startdir/pkg/usr/share/$DOCS" ]; then
			mv $startdir/pkg/usr/share/$DOCS $startdir/pkg/usr/$DOCS
			if [[ ! "$(ls $startdir/pkg/usr/share)" ]]; then
				rm -rf $startdir/pkg/usr/share
			fi
		fi
		if [ -d "$startdir/pkg/usr/$DOCS" ]; then
			# I've never seen symlinks in info pages....
			if [ "$DOCS" == "man" ]; then
				(cd $startdir/pkg/usr/$DOCS
				for manpagedir in $(find . -type d -name "man*" 2> /dev/null) ; do
					( cd $manpagedir
					for eachpage in $( find . -type l -maxdepth 1 2> /dev/null) ; do
						ln -s $( readlink $eachpage ).gz $eachpage.gz
						rm $eachpage
					done )
				done)
			fi
			find $startdir/pkg/usr/$DOCS -type f -exec gzip -9 '{}' \;
		fi
	done
	[ -a $startdir/pkg/usr/info/dir.gz ] && rm -f $startdir/pkg/usr/info/dir.gz
}

set_post_permissions() {
	for DIRS in usr/share/icons usr/doc; do
		if [ -d "$startdir/pkg/$DIRS" ]; then
			if [ "$DIRS" == "usr/doc" ]; then
				find $startdir/pkg/$DIRS -type f -exec chmod 644 {} \;
				find $startdir/pkg/$DIRS -type d -exec chmod 755 {} \;
			fi
		fi
		[ -d $startdir/pkg/$DIRS ] && chown root:root -R $startdir/pkg/$DIRS
	done
	[ -d $startdir/pkg/usr/bin ] && find $startdir/pkg/usr/bin -user root -group bin -exec chown root:root {} \;
}

copy_build_script() {
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver/
	cp $startdir/build-$pkgname.sh $startdir/pkg/usr/src/$pkgname-$pkgver/build-$pkgname.sh
	[ -f $startdir/SLKBUILD ] && cp $startdir/SLKBUILD	$startdir/pkg/usr/src/$pkgname-$pkgver/SLKBUILD
}

create_package() {
	ls -lR $startdir/pkg
	cd $startdir/pkg
	/sbin/makepkg -l y -c n $startdir/$package.txz
	cd $startdir
	md5sum $package.txz > $startdir/$package.md5
}

strip_binaries() {
	cd $startdir/pkg
	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
}
#########End Redundant Code#####################################
#########Begin Non Redundant Code##############################

prepare_directory() {
	mkdir $startdir/src
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver
	for SOURCES in ${source[@]}; do
		protocol=$(echo $SOURCES | sed 's|:.*||')
	        file=$(basename $SOURCES | awk -F= '{print $NF}')
		if [ ! -f "$file" ]; then
			if [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
				echo -e "\nDownloading $(basename $SOURCES)\n"
        	                wget $SOURCES -O $file
				if [ ! "$?" == "0" ]; then
					echo "Download failed"
					exit 2
				fi 
			else
				echo "$SOURCES does not appear to be a url nor is it in the directory"
				exit 2
			fi
		fi
		cp -R $file $startdir/src
		if ! [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
			if ! [[  -eq 1 ]]; then
				cp -R $startdir/$(basename $SOURCES) $startdir/pkg/usr/src/$pkgname-$pkgver/
			fi
		fi
	done
}

extract_source() {
	cd $startdir/src
	if [[ "$(ls $startdir/src)" ]]; then	
		for FILES in ${source[@]}; do
	        	FILES="$(basename $FILES | awk -F= '{print $NF}')"
			file_type=$(file -biz "$FILES")
			unset cmd
			case "$file_type" in
				*application/x-tar*)
					cmd="tar -xf" ;;
				*application/x-zip*)
					cmd="unzip" ;;
				*application/zip*)
					cmd="unzip" ;;
				*application/x-gzip*)
					cmd="gunzip -d -f" ;;
				*application/x-bzip*)
					cmd="bunzip2 -f" ;;
				*application/x-xz*)
					cmd="xz -d -f" ;;
				*application/x-lzma*)
					cmd="lzma -d -f" ;;
			esac
			if [ "$cmd" != "" ]; then
				echo "$cmd $FILES"
	        	        $cmd $FILES
			fi
		done
	elif [ ! "$source" ]; then
		echo -n "" # lame fix
	else
		echo "no files in the src directory $startdir/src"
		exit 2
	fi
}

build() {
	#
	# build live555 lib for static linking
	#
	cd $startdir/src/live
	sed -i "s/\ -O2\ /\ $CFLAGS\ /" config.linux || return 1
	./genMakefiles linux || return 1
	make -j3 || return 1

	#
	# build vlc
	#
	cd $startdir/src/${pkgname}-$pkgver

	# patch default font
	sed -i 's#truetype/freefont/FreeSerifBold.ttf#TTF/FreeSansBold.ttf#' modules/misc/freetype.c || return 1

	# -march=x86_64 is not allowed, so...
	if [ "$arch" = "x86_64" ]; then
		TUNING=generic
	else
		TUNING=$arch
	fi

	./configure --prefix=/usr  --libdir=/usr/lib${LIBDIRSUFFIX} --localstatedir=/var --sysconfdir=/etc \
		--enable-shared \
		--disable-static \
		--enable-hal \
		--enable-mtp \
		--enable-dbus \
		--enable-dbus-control \
		--enable-release \
		--enable-notify \
		--enable-lua \
		--enable-httpd \
		--enable-vlm \
		--enable-taglib \
		--enable-audioscrobbler \
		--enable-live555 \
		--with-live555-tree=$startdir/src/live \
		--enable-dvdread \
		--enable-dvdnav \
		--enable-dvbpsi \
		--enable-v4l2 \
		--enable-pvr \
		--enable-gnomevfs \
		--enable-libcdio \
		--enable-cddax \
		--enable-libcddb \
		--disable-vcdx \
		--enable-cdda \
		--enable-vcd \
		--enable-dvb \
		--enable-screen \
		--enable-ogg \
		--enable-mkv \
		--enable-mod \
		--enable-mpc \
		--enable-mad \
		--enable-avcodec \
		--enable-avformat \
		--enable-swscale \
		--enable-postproc \
		--enable-faad \
		--disable-twolame \
		--enable-real \
		--enable-realrtsp \
		--enable-libsysfs \
		--enable-libtar \
		--enable-a52 \
		--enable-dca \
		--enable-flac \
		--enable-libmpeg2 \
		--enable-vorbis \
		--disable-tremor \
		--enable-speex \
		--disable-tarkin \
		--enable-theora \
		--disable-dirac \
		--enable-schroedinger \
		--enable-png \
		--enable-x264 \
		--disable-fluidsynth \
		--disable-zvbi \
		--enable-telx \
		--disable-csri \
		--disable-libass \
		--disable-asademux \
		--disable-cmml \
		--disable-kate \
		--disable-tiger \
		--enable-x11 \
		--enable-xvideo \
		--enable-glx \
		--enable-xvmc \
		--enable-xinerama \
		--enable-xcb \
		--disable-opengl \
		--enable-sdl \
		--enable-sdl-image \
		--enable-freetype \
		--enable-fribidi \
		--enable-fontconfig \
		--enable-libxml2 \
		--disable-svg \
		--enable-snapshot \
		--disable-fb \
		--disable-mga \
		--disable-omapfb \
		--disable-svgalib \
		--disable-directfb \
		--disable-ggi \
		--enable-caca \
		--disable-oss \
		--disable-pulse \
		--disable-portaudio \
		--enable-alsa \
		--disable-waveout \
		--disable-macosx-audio \
		--disable-hd1000a \
		--disable-jack \
		--disable-cyberlink \
		--disable-upnp \
		--enable-skins2 \
		--disable-pda \
		--disable-maemo \
		--enable-qt4 \
		--enable-ncurses \
		--disable-fbosd \
		--enable-visual \
		--disable-galaktos \
		--disable-goom \
		--disable-atmo \
		--disable-bonjour \
		--disable-lirc \
		--enable-libgcrypt \
		--enable-gnutls \
		--disable-remoteosd \
		--disable-update-check \
		--disable-loader \
		--enable-vlc \
		--disable-mozilla \
		--disable-testsuite \
		--with-tuning=$TUNING || return 1

	LANG=en_US make -j3 || return 1
	make DESTDIR=$startdir/pkg install

	# install a subtitle font
	mkdir -p $startdir/pkg/usr/share/fonts/TTF
	cp share/skins2/fonts/FreeSansBold.ttf $startdir/pkg/usr/share/fonts/TTF/ || return 1
}

create_slackdesc() {
mkdir $startdir/pkg/install
cat <<"EODESC" >$startdir/pkg/install/slack-desc
vlc: vlc - a multimedia player
vlc: 
vlc: VLC (initially VideoLAN Client) is a highly portable multimedia player
vlc: for various A/V formats (MPEG-1, MPEG-2, MPEG-4, DivX, mp3, ogg,...)
vlc: as well as DVDs, VCDs, and various streaming protocols. It can also be
vlc: used as a server to stream in unicast or multicast in IPv4 or IPv6 on
vlc: a high-bandwidth network.
vlc: 
vlc: 
vlc: 
vlc: 
EODESC
}

copy_docs() {
	for stuff in ${docs[@]}; do
		if [ ! -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
			mkdir -p $startdir/pkg/usr/doc/$pkgname-$pkgver
		fi
		find $startdir/src -type f -iname "$stuff" -exec cp -R '{}' $startdir/pkg/usr/doc/$pkgname-$pkgver \;
	done
}
create_source_file(){
	[ -f $package.src ] && rm $package.src
	if [ ! -z $sourcetemplate ]; then
		echo $sourcetemplate/SLKBUILD >> $package.src
		echo $sourcetemplate/build-$pkgname.sh >> $package.src
		for SOURCES in ${source[@]}; do
			protocol=$(echo $SOURCES | sed 's|:.*||')
			if ! [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
				if [ ! -z $sourcetemplate ]; then
					echo $sourcetemplate/$(basename $SOURCES) >> $package.src
				else
					echo $(basename $SOURCES) >> $package.src
				fi
			else
				echo $SOURCES >> $package.src
			fi
		done
	fi
}
post_checks(){
	# Ideas taken from src2pkg :)
	if [ -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
		for DIRS in usr/doc/$pkgname-$pkgver usr/doc; do
			cd $startdir/pkg/$DIRS
			if [[ $(find . -type f) = "" ]] ; then
				cd ..
				rmdir $DIRS
			fi
		done
	fi
	# if the docs weren't deleted ...
	if [ -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
		cd $startdir/pkg/usr/doc/$pkgname-$pkgver
		#remove zero lenght files
		if [[ $(find . -type f -size 0) ]]; then
			echo "Removing some zero lenght files"
			find . -type f -size 0 -exec rm -f {} \;
		fi
	fi
	# check if we need to add code to handle info pages
	if [[ -d $startdir/pkg/usr/info ]] && [[ ! $(grep install-info $startdir/pkg/install/doinst.sh &> /dev/null) ]] ; then
		echo "Found info files - Adding install-info command to doinst.sh"
		INFO_LIST=$(ls -1 $startdir/pkg/usr/info)
		echo "" >> $startdir/pkg/install/doinst.sh
		echo "if [ -x usr/bin/install-info ] ; then" >> $startdir/pkg/install/doinst.sh
		for page in $(echo $INFO_LIST) ; do
			echo " usr/bin/install-info --info-dir=usr/info usr/info/$page 2>/dev/null" >> $startdir/pkg/install/doinst.sh
		done
		echo "fi" >> $startdir/pkg/install/doinst.sh
	fi
	[[ -e $startdir/pkg/usr/info/dir ]] && rm -f $startdir/pkg/usr/info/dir

	if [ -d $startdir/pkg/etc ]; then
		cd $startdir/pkg/
		for conf in $(find ./etc -type f) ; do
			conf=${conf: 2}
			dotnew=( "${dotnew[@]}" "$conf" )
		done
	fi
	if [[ "$dotnew" ]]; then
        for files in ${dotnew[@]} ; do
                fullfile="${startdir}/pkg/${files}"
                if [ -e "$fullfile" ]; then
                        mv $fullfile ${fullfile}.new
                else
                        echo "$fullfile was not found"
                        exit 2
                fi
        done
        cat<<"EODOTNEW" >>$startdir/pkg/install/doinst.sh
#Added by slkbuild 0.6.1
dotnew() {
        NEW="${1}.new"
        OLD="$1"
        if [ ! -e $OLD ]; then
                mv $NEW $OLD
        elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
                rm $NEW
        fi
}
EODOTNEW
for i in ${dotnew[@]}; do
echo "dotnew $i" >> $startdir/pkg/install/doinst.sh
done
fi
}

####End Non Redundant Code############################

#Variables

startdir=$(pwd)
SRC=$startdir/src
PKG=$startdir/pkg

pkgname=vlc
pkgver=1.0.4
pkgrel=1tm
arch=x86_64
package=$pkgname-$pkgver-$arch-1tm
source=("http://download.videolan.org/pub/vlc/1.0.4/vlc-1.0.4.tar.bz2" "http://www.live555.com/liveMedia/public/live555-latest.tar.gz")
docs=(AUTHORS ChangeLog COPYING MAINTAINERS NEWS README THANKS)
export CFLAGS="-O2 -fPIC"
export CXXFLAGS="-O2 -fPIC"
export LIBDIRSUFFIX="64"

#Execution

check_for_root
clean_old_builds
prepare_directory
extract_source
set_pre_permissions
build
if [ ! "$?" = "0" ]; then
	echo "build() failed."
	exit 2
fi
create_slackdesc
post_checks
copy_docs
strip_binaries
gzip_man_and_info_pages
set_post_permissions
copy_build_script
create_package
create_source_file
echo "Package has been built."
echo "Cleaning pkg and src directories"
clean_dirs
